#
# spec file for package libcxl
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libcxl
Version:        1.7
Release:        3.4
%define soversion 1
Summary:        Coherent accelerator interface
License:        Apache-2.0
Group:          Development/Libraries/C and C++
URL:            https://github.com/ibm-capi/libcxl
Source:         %{name}-%{version}.tar.gz
Patch1:         remove_2_backslashes_in_shell_call.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  glibc
ExclusiveArch:  ppc64 ppc64le

%description
Coherent accelerator interface (refer to lib package with soversion)

%package -n %{name}%{soversion}
Summary:        Coherent accelerator shared library
Group:          System/Libraries

%description -n %{name}%{soversion}
The coherent accelerator interface is designed to allow the coherent
connection of accelerators (FPGAs and other devices) to a POWER system.
Coherent in this context means that the accelerator and CPUs can both access
system memory directly and with the same effective addresses. IBM refers to
this as the Coherent Accelerator Processor Interface (CAPI). In the Linux
world, it is referred to by the name CXL to avoid confusion with the ISDN
CAPI subsystem.

The Linux kernel interacts with the device POWER Service Layer (PSL).
Userland interacts with the device Accelerator Function Unit (AFU). See the
Linux kernel source file Documentation/powerpc/cxl.txt for a detailed
description of the coherent accelerator interface.

The CXL library provides a userland API to coherently attached devices. CXL
devices can be enumerated. Their capabilities can be queried. AFUs can be
opened, attached to the current process, and started. Jobs, described by AFU
specific Work Element Descriptors (WEDs), can be submitted and executed by
AFUs. AFU MMIO space can be mapped into the current process memory, and AFUs
can be configured and controlled via MMIO reads and writes.

%package devel
Summary:        Coherent accelerator interface header files and man pages
Group:          Development/Libraries/C and C++
Requires:       %name%soversion = %version

%description devel
Coherent accelerator interface header files and man pages
only for development purposes.

%prep
%autosetup -p1

%build
make CFLAGS="%{optflags} -fPIC" V=1
mkdir -p build/man3
cp -p man3/*.3 build/man3

%install
make DESTDIR=%{buildroot} prefix=/usr install
mkdir -p %{buildroot}%{_mandir}
cp -a build/man3 %{buildroot}%{_mandir}/

%files -n %{name}%{soversion}
%defattr(-,root,root)
%doc LICENSE
%doc README.md
%{_libdir}/libcxl.so.*

%post -n %{name}%{soversion} -p /sbin/ldconfig

%postun -n %{name}%{soversion} -p /sbin/ldconfig

%files devel
%defattr(-,root,root)
%doc LICENSE
%{_includedir}/*
%{_mandir}/man3/*
%{_libdir}/libcxl.so

%changelog
* Thu Feb 29 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Fri Jun 12 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add remove_2_backslashes_in_shell_call.patch
* Wed May 30 2018 normand@linux.vnet.ibm.com
- Update v1.7
  New api cxl_get_tunneled_ops_supported
- Update v1.6
  new functions cxl_afu_host_thread_wait(), cxl_work_disable_wait(),
  cxl_work_enable_wait() and cxl_work_get_tid() are now unconditionally
  built and exported.
- remove libcxl_sysmacros.patch embeded upstream.
* Thu Jun  8 2017 normand@linux.vnet.ibm.com
- Update v1.5
  * libcxl: Check afu link when read from PSA mmio return all FFs
  * Makefile: add -Werror
  * Use _DEFAULT_SOURCE rather than _BSD_SOURCE
  * Fix sparse warnings
  * Added #include <asm/types.h>
  * Man pages: document flags CXL_MMIO_{BIG,HOST,LITTLE}_ENDIAN
  * Makefile: do not fail if target symlink already exists.
  * Man pages: clarify mmio read/write alignment constraints.
  * Create LIBSONAME link
  * sysfs: Fix a boundary condition check for OUT_OF_RANGE macro
- remove libcxl_create_soname_link.patch part of above update.
- add libcxl_sysmacros.patch to avoid warning at build time
* Tue May 31 2016 normand@linux.vnet.ibm.com
- Update v1.4
  * New API function cxl_get_psl_timebase_synced.
  * Simplify implementation of OUT_OF_RANGE macro
  * libcxl add install target
  * use LDFLAGS from the env
  * libcxl set default soname and interface version
  * Add extern "C" to libcxl.h for compatibility with C++ projects
  * typo error in 3 man pages
  * Add SONAME support in Makefile
- remove embeded patches:
  libcxl_typo_correction_man_pages.patch
  libcxl_add_soname_in_Makefile.patch
- new libcxl_create_soname_link.patch
* Thu Mar 24 2016 jengelh@inai.de
- RPM group reclassification
* Thu Mar  3 2016 jloeser@suse.com
- spec update for SLES12 (FATE#320440)
* Thu Mar  3 2016 normand@linux.vnet.ibm.com
- Add missing -fPIC and use default optflags in CFLAGS
  and do make to be verbose.
* Sun Feb 21 2016 jengelh@inai.de
- Drop Fedora parts (no build targets exist). Drop Debian dots
  from description. Add missing requires.
* Fri Jan 22 2016 normand@linux.vnet.ibm.com
- do not ship static library as suggested by packaging guidelines
* Wed Jan 20 2016 normand@linux.vnet.ibm.com
- new libcxl_typo_correction_man_pages.patch
- spec update for fedora
* Wed Jan 20 2016 normand@linux.vnet.ibm.com
- spec update to avoid shell creation for post/postun actions
* Tue Jan 19 2016 normand@linux.vnet.ibm.com
- update the libcxl_add_soname_in_Makefile.patch
* Tue Jan 19 2016 normand@linux.vnet.ibm.com
- Initial package creation for libcxl from upstream url
  with patch to handle soname
  libcxl_add_soname_in_Makefile.patch
  upstream url: https://github.com/ibm-capi/libcxl
